==> knewkarma-1.4.1.0.tar.gz: knewkarma-1.4.1.0/README.md <==
# Knew Karma

**Reddit** Data Analysis Toolkit.

[![.Net](https://img.shields.io/badge/Visual%20Basic%20.NET-5C2D91?style=flat&logo=.net&logoColor=white)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3A%22Visual+Basic+.NET%22&type=code) [![Python](https://img.shields.io/badge/Python-3670A0?style=flat&logo=python&logoColor=ffdd54)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3APython&type=code) [![Docker](https://img.shields.io/badge/Dockefile-%230db7ed.svg?style=flat&logo=docker&logoColor=white)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3ADockerfile&type=code) [![PyPI - Version](https://img.shields.io/pypi/v/knewkarma?style=flat&logo=pypi&logoColor=ffdd54&label=PyPI&labelColor=3670A0&color=3670A0)](https://pypi.org/project/knewkarma)  [![BuyMeACoffee](https://img.shields.io/badge/Buy%20Me%20a%20Coffee-ffdd00?style=flat&logo=buy-me-a-coffee&logoColor=black)](https://buymeacoffee.com/_rly0nheart)

# 📃 Features

- [x] Has got both a Command-Line and Graphical User Interface instance.
- [x] Dark mode (GUI)
- [x] Saves results to either a **JSON** or **CSV** file.
- [x] Gets **Posts**, **Comments** and **Profile** data of a specified **User**.
- [x] Gets **Posts** and **Profile** data of a specified of a **Subreddit**.
- [x] Returns **Posts** from Reddit's **front page**.
- [x] Returns **Posts** from a specified **listing**.
- [x] **Searches** for posts matching a given query form **all over Reddit**.

***

# 📖 Documentation

*Refer to the [Wiki](https://github.com/bellingcat/knewkarma/wiki) for Installation, Usage and Uninstallation
instructions.*
***
[![me](https://github.com/bellingcat/reddit-post-scraping-tool/assets/74001397/21e0bb33-7a84-45d6-92ba-00e40891ba31)](https://about.me/rly0nheart)

==> knewkarma-1.5.0.0.tar.gz: knewkarma-1.5.0.0/README.md <==
![knewkarma](https://github.com/bellingcat/knewkarma/assets/74001397/c2ff1a3d-a204-436d-8d67-a81bacd416fd)


A **Reddit** Data Analysis Toolkit.

[![.Net](https://img.shields.io/badge/Visual%20Basic%20.NET-5C2D91?style=flat&logo=.net&logoColor=white)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3A%22Visual+Basic+.NET%22&type=code) [![Python](https://img.shields.io/badge/Python-3670A0?style=flat&logo=python&logoColor=ffdd54)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3APython&type=code) [![Docker](https://img.shields.io/badge/Dockefile-%230db7ed.svg?style=flat&logo=docker&logoColor=white)](https://github.com/search?q=repo%3Abellingcat%2Fknewkarma++language%3ADockerfile&type=code) [![PyPI - Version](https://img.shields.io/pypi/v/knewkarma?style=flat&logo=pypi&logoColor=ffdd54&label=PyPI&labelColor=3670A0&color=3670A0)](https://pypi.org/project/knewkarma)  [![BuyMeACoffee](https://img.shields.io/badge/Buy%20Me%20a%20Coffee-ffdd00?style=flat&logo=buy-me-a-coffee&logoColor=black)](https://buymeacoffee.com/_rly0nheart)


# Features

- [x] Has got both a Command-Line and Graphical User Interface instance.
- [x] Dark mode (GUI)
- [x] Saves results to either a **JSON** or **CSV** file.
- [x] Gets **Posts**, **Comments** and **Profile** data of a specified **User**.
- [x] Gets **Posts** and **Profile** data of a specified of a **Subreddit**.
- [x] Returns **Posts** from Reddit's **front page**.
- [x] Returns **Posts** from a specified **listing**.
- [x] **Searches** for posts matching a given query form **all over Reddit**.

# Documentation

*[Refer to the Wiki](https://github.com/bellingcat/knewkarma/wiki) for Installation, Usage and Uninstallation
instructions.*
***
[![me](https://github.com/bellingcat/knewkarma/assets/74001397/efd19c7e-9840-4969-b33c-04087e73e4da)](https://about.me/rly0nheart)
